@@ -6,7 +6,7 @@ sampleCat <- function(x) {
     x <- as.factor(x)
   s <- summary(x)
   s <- s[s != 0]
-  sample(names(s), 1, prob = s)
+  sample(names(s), 1, prob=s)
 }
 
 #' @rdname microaggrGower
@@ -33,9 +33,9 @@ which.minN <- function(x, n) {
 }
 
 ## Wrapper function for gowerD
-gowerD <- function(data.x, data.y = data.x, weights = NULL, numerical, factors, orders, mixed, levOrders, mixed.constant) {
+gowerD <- function(data.x, data.y=data.x, weights=NULL, numerical, factors, orders, mixed, levOrders, mixed.constant) {
   maxplus1 <- function(x) {
-    x[is.na(x)] <- max(x, na.rm = TRUE) + 1
+    x[is.na(x)] <- max(x, na.rm=TRUE) + 1
     x
   }
   # weights <- rep(1,ncol(data.x))
@@ -44,8 +44,8 @@ gowerD <- function(data.x, data.y = data.x, weights = NULL, numerical, factors,
     data.y[, i] <- as.numeric(data.y[, i])
   }
   weightind <- order(match(colnames(data.x), c(numerical, factors, orders, mixed)))
-  data.x <- data.x[, c(numerical, factors, orders, mixed), drop = FALSE]
-  data.y <- data.y[, c(numerical, factors, orders, mixed), drop = FALSE]
+  data.x <- data.x[, c(numerical, factors, orders, mixed), drop=FALSE]
+  data.y <- data.y[, c(numerical, factors, orders, mixed), drop=FALSE]
 
   justone <- FALSE
   if (nrow(data.y) == 1) {
@@ -57,9 +57,9 @@ gowerD <- function(data.x, data.y = data.x, weights = NULL, numerical, factors,
   levOrders <- as.numeric(levOrders)
 
   out <- .Call("gowerD", data.x, data.y, weights[weightind], c(length(numerical), length(factors),
-    length(orders), length(mixed)), levOrders, mixed.constant, PACKAGE = "sdcMicro")
+    length(orders), length(mixed)), levOrders, mixed.constant, PACKAGE="sdcMicro")
   if (justone) {
-    out <- out$delta[, 1, drop = FALSE]
+    out <- out$delta[, 1, drop=FALSE]
   } else {
     out <- out$delta
   }
@@ -68,15 +68,15 @@ gowerD <- function(data.x, data.y = data.x, weights = NULL, numerical, factors,
 
 ## Fuer data.frame, kNN-Suche auf Basis der Gowerdistance und Aggregation mit numFun bzw.
 ## catFun
-maGowerWORK <- function(data, variables = colnames(data), aggr = 3, dist_var = variables, by = NULL,
-  mixed = NULL, mixed.constant = NULL, trace = FALSE, weights = NULL, numFun = mean,
-  catFun = sampleCat, addRandom = FALSE) {
+maGowerWORK <- function(data, variables=colnames(data), aggr=3, dist_var=variables, by=NULL,
+  mixed=NULL, mixed.constant=NULL, trace=FALSE, weights=NULL, numFun=mean,
+  catFun=sampleCat, addRandom=FALSE) {
 
   if (!is.null(by)) {
     if (!all(by %in% colnames(data)))
       stop("'by'-variable not found in data set.\n'by' should be a vector of\n              variable names to split the dataset before \n applying microaggregation.")
-    splfac <- as.factor(apply(data[, by, drop = FALSE], 1, function(x) paste(as.character(x),
-      collapse = "--")))
+    splfac <- as.factor(apply(data[, by, drop=FALSE], 1, function(x) paste(as.character(x),
+      collapse="--")))
     spl <- split(data, splfac)
   } else {
     splfac <- as.factor(rep(1, nrow(data)))
@@ -140,11 +140,11 @@ maGowerWORK <- function(data, variables = colnames(data), aggr = 3, dist_var = v
   if (is.null(mixed.constant))
     mixed.constant <- rep(0, length(mixedX))
   spl <- lapply(spl, function(dataSpl) {
-    gd <- gowerD(dataSpl[, dist_var], dataSpl[, dist_var], weights = weights, numericalX,
-      factorsX, ordersX, mixedX, levOrdersX, mixed.constant = mixed.constant)
+    gd <- gowerD(dataSpl[, dist_var], dataSpl[, dist_var], weights=weights, numericalX,
+      factorsX, ordersX, mixedX, levOrdersX, mixed.constant=mixed.constant)
     which.minNk <- function(x) 1
-    cmd <- paste("which.minNk <- function(x)which.minN(x,", aggr, ")", sep = "")
-    eval(parse(text = cmd))
+    cmd <- paste("which.minNk <- function(x)which.minN(x,", aggr, ")", sep="")
+    eval(parse(text=cmd))
     mindi <- apply(gd, 2, which.minNk)
     erg <- as.matrix(mindi)
     if (addRandom)
@@ -176,11 +176,8 @@ maGowerWORK <- function(data, variables = colnames(data), aggr = 3, dist_var = v
 #' with the most occurrences and random if the maximum is not unique.
 #'
 #' @name microaggrGower
-#' @aliases microaggrGower microaggrGower-methods
-#' microaggrGower,data.frame-method microaggrGower,sdcMicroObj-method sampleCat
-#' maxCat
 #' @docType methods
-#' @param obj an object of class sdcMicroObj or a data frame
+#' @param obj \code{\link{sdcMicroObj-class}}-object or a \code{data.frame}
 #' @param variables character vector with names of variables to be aggregated
 #' (Default for sdcMicroObj is all keyVariables and all numeric key variables)
 #' @param aggr aggregation level (default=3)
@@ -219,49 +216,52 @@ maGowerWORK <- function(data, variables = colnames(data), aggr = 3, dist_var = v
 #'   numVars=c('expend','income','savings'), w='sampling_weight')
 #'
 #' sdc <- microaggrGower(sdc)
-#'
-setGeneric("microaggrGower", function(obj, variables = NULL, aggr = 3, dist_var = NULL, by = NULL,
-  mixed = NULL, mixed.constant = NULL, trace = FALSE, weights = NULL, numFun = mean,
-  catFun = sampleCat, addRandom = FALSE) {
 
-  standardGeneric("microaggrGower")
+microaggrGower <- function(obj, variables=NULL, aggr=3, dist_var=NULL, by=NULL,
+  mixed=NULL, mixed.constant=NULL, trace=FALSE, weights=NULL, numFun=mean,
+  catFun=sampleCat, addRandom=FALSE) {
+  microaggrGowerX(obj=obj, variables=variables, aggr=aggr, dist_var=dist_var, by=by,
+    mixed=mixed, mixed.constant=mixed.constant, trace=trace, weights=weights, numFun=numFun,
+    catFun=catFun, addRandom=addRandom)
+}
+
+setGeneric("microaggrGowerX", function(obj, variables=NULL, aggr=3, dist_var=NULL, by=NULL,
+  mixed=NULL, mixed.constant=NULL, trace=FALSE, weights=NULL, numFun=mean,
+  catFun=sampleCat, addRandom=FALSE) {
+
+  standardGeneric("microaggrGowerX")
 })
 
-setMethod(f = "microaggrGower", signature = c("sdcMicroObj"),
-  definition = function(obj, variables = NULL, aggr = 3, dist_var = NULL, by = NULL, mixed = NULL,
-  mixed.constant = NULL, trace = FALSE, weights = NULL, numFun = mean, catFun = sampleCat, addRandom = FALSE) {
+setMethod(f="microaggrGowerX", signature=c("sdcMicroObj"),
+  definition=function(obj, variables=NULL, aggr=3, dist_var=NULL, by=NULL, mixed=NULL,
+  mixed.constant=NULL, trace=FALSE, weights=NULL, numFun=mean, catFun=sampleCat, addRandom=FALSE) {
   o <- extractManipData(obj)
   if (is.null(by) && "sdcGUI_strataVar" %in% colnames(o))
     by <- "sdcGUI_strataVar"
-  nV <- get.sdcMicroObj(obj, type = "numVars")
-  kV <- get.sdcMicroObj(obj, type = "keyVars")
+  nV <- get.sdcMicroObj(obj, type="numVars")
+  kV <- get.sdcMicroObj(obj, type="keyVars")
   if (is.null(variables))
     variables <- colnames(o)[c(nV, kV)]
   if (is.null(dist_var))
     dist_var <- variables
-  res <- maGowerWORK(o, variables = variables, aggr = aggr, dist_var = dist_var, by = by,
-    mixed = mixed, mixed.constant = mixed.constant, trace = trace, weights = weights, numFun = numFun,
-    catFun = catFun, addRandom = addRandom)
+  res <- maGowerWORK(o, variables=variables, aggr=aggr, dist_var=dist_var, by=by,
+    mixed=mixed, mixed.constant=mixed.constant, trace=trace, weights=weights, numFun=numFun,
+    catFun=catFun, addRandom=addRandom)
 
-  obj <- set.sdcMicroObj(obj, type = "manipNumVars", input = list(as.data.frame(res[, nV])))
-  obj <- set.sdcMicroObj(obj, type = "manipKeyVars", input = list(as.data.frame(res[, kV])))
+  obj <- set.sdcMicroObj(obj, type="manipNumVars", input=list(as.data.frame(res[, nV])))
+  obj <- set.sdcMicroObj(obj, type="manipKeyVars", input=list(as.data.frame(res[, kV])))
   obj <- dRisk(obj)
   obj <- dUtility(obj)
   obj <- calcRisks(obj)
   obj
 })
 
-setMethod(f = "microaggrGower", signature = c("data.frame"),
-  definition = function(obj, variables = colnames(data), aggr = 3, dist_var = variables, by = NULL,
-  mixed = NULL, mixed.constant = NULL, trace = FALSE, weights = NULL, numFun = mean,
-  catFun = sampleCat, addRandom = FALSE) {
+setMethod(f="microaggrGowerX", signature=c("data.frame"),
+  definition=function(obj, variables=colnames(data), aggr=3, dist_var=variables, by=NULL,
+  mixed=NULL, mixed.constant=NULL, trace=FALSE, weights=NULL, numFun=mean,
+  catFun=sampleCat, addRandom=FALSE) {
 
-  maGowerWORK(data = obj, variables = variables, dist_var = dist_var, by = by, mixed = mixed,
-    mixed.constant = mixed.constant, trace = trace, weights = weights, numFun = numFun,
-    catFun = catFun, addRandom = addRandom)
+  maGowerWORK(data=obj, variables=variables, dist_var=dist_var, by=by, mixed=mixed,
+    mixed.constant=mixed.constant, trace=trace, weights=weights, numFun=numFun,
+    catFun=catFun, addRandom=addRandom)
 })
-# data(testdata,package='sdcMicro) for(i in c(1:7,9))testdata[,i] <-
-# as.factor(testdata[,i])
-
-# test <-
-# maG(testdata,variables=C('relat','age','expend'),dist_var=C('age','sex','income','savings'),BY=C('urbrur','roof'))
