@@ -579,20 +579,33 @@ output$ui_reset_var <- renderUI({
 output$ui_show_microdata <- renderUI({
   my_data_dt = reactive({
     datatable(inputdata(),
-    rownames = FALSE,
-    selection="none",
-    options = list(scrollX=TRUE, lengthMenu=list(c(10, 25, 100, -1), c('10', '20', '100', 'All')), pageLength=25))
+              rownames = FALSE,
+              selection="none",
+              options = list(scrollX=TRUE, lengthMenu=list(c(10, 25, 100, -1), c('10', '20', '100', 'All')), pageLength=25))
   })
   #, options = list(scrollX=TRUE, lengthMenu=list(c(10, 25, 100, -1), c('10', '20', '100', 'All')), pageLength=25), filter="top", rownames=FALSE
   output$tab_inputdata <- DT::renderDataTable({
     my_data_dt()
   })
-
+  
   txt_microdata <- paste0("In this tab you can manipulate the data to prepare for setting up an object of class",code("sdcMicroObj"),"in the Anonymize tab. ")
   txt_microdata <- paste0(txt_microdata, "The loaded dataset is",code(obj$microfilename),"and consists of",code(nrow(obj$inputdata)),"observations and ",code(ncol(obj$inputdata)),"variables.")
+  if(is.null(attr(obj$inputdata, "dropped"))){
+    txt_microdata <- paste0(txt_microdata, "No variables were dropped because of all missing values.")
+  }else{
+    txt_microdata <- paste0(txt_microdata, code(length(attr(obj$inputdata, "dropped"))), "variable(s) was/were dropped because of all missing values: ")
+    #lapply(attr(obj$inputdata, "dropped"), function(x) {txt_microdata <- paste0(txt_microdata, x)})
+    #attr(obj$inputdata, "dropped")
+  }
   out <- fluidRow(
-    column(12, h4("Loaded microdata"), align="center"),
-    column(12, p(HTML(txt_microdata)), align="center"))
+    column(12, h4("Loaded microdata"), align="center"))
+  if(is.null(attr(obj$inputdata, "dropped"))){
+    out <- list(out, fluidRow(
+      column(12, p(HTML(txt_microdata)), align="center")))
+  }else{
+    out <- list(out, fluidRow(
+      column(12, list(HTML(txt_microdata), code(lapply(attr(obj$inputdata, "dropped"), function(x) {x}))), align="center")))
+  }
   out <- list(out, fluidRow(
     column(12, dataTableOutput("tab_inputdata"))))
   return(out)
